# man page: https://rycee.gitlab.io/home-manager/options.html

{ nixpkgs }:
{ config, pkgs, lib, ... }:
{

  home = {
    stateVersion = "21.11"; # No tocar esto
    username = "fabian";
    homeDirectory = "/home/fabian";
    packages = import ./path.nix pkgs;
  };

  nix.registry."system".to = {
    type = "path";
    path = "/home/fabian/nix";
  };

  nix.registry."nixpkgs".flake = nixpkgs;

  xsession.enable = true;
  xsession.windowManager.i3 = {
    enable = true;
    package = pkgs.i3-gaps;
    extraConfig = import ./i3 pkgs;
  };

  nixpkgs.config.allowUnfree = true;

  programs.home-manager.enable = true;
  programs.neovim.enable = true;
  programs.zsh = {
    enable = true;
    enableSyntaxHighlighting = true;
    initExtra = import ./zshrc.nix pkgs;
  };

  programs.kitty = {
    enalbe = true;
    extraConfig = ./kitty.conf.nix
  };

  services.betterlockscreen = {
    enable = true;
    # confiugrar luego
  };

  # configurable = [ neovim keyboardlayout pulsaudio rofi ];

  services.picom = {
    enable = true;
  };

  services.polybar = {
    enable = true;
    script = import ./i3/polybar/launch.sh.nix;
    extraConfig = import ./i3/polybar/config.nix;
  };

  services.dunst = {
    enable = true;
  };

  programs.vscode = {
    enable = true;
    package = pkgs.vscodium;
    userSettings = {
      "files.autoSave" = "onFocusChange";
      "explorer.confirmDelete" = false;
      "explorer.confirmDragAndDrop" = false;
    };
  };

  programs.git = {
    enable = true;
    userEmail = "fabian@cluster451.org";
    userName = "Fabián Montero";
    signing.key = "E77A808BF9A955D668EEEA6473FA9C9CB5F0249B";
  };
}

